@@ -846,9 +846,8 @@ heterocitation_authors<-function(gr, infLimitYear, supLimitYear, pub_threshold=0
   
 }
 
-# Calculate p-value based on Monte Carlo runs with random reassignment of node corpus
-# to evaluate significance of heterocitation statistics
-p_value_Dx <- function(gr, labels, infYearLimit, supYearLimit, rep=20) {
+# Monte Carlo runs with random reassignment of node corpus to evaluate significance of heterocitation statistics
+MC_baseline_distribution <- function(gr, labels, infYearLimit, supYearLimit, rep=20) {
   gr_loc<-gr
   res1<-c()
   res2<-c()
@@ -877,6 +876,24 @@ p_value_Dx <- function(gr, labels, infYearLimit, supYearLimit, rep=20) {
   ret
 }
 
+significance_Dx <- function(value, control, normality_threshold=0.05) {
+  pv<-NA
+  # Test normality
+  tn<-stats::shapiro.test(control)
+  if (tn$p.value > normality_threshold) {
+    print("Distribution is normal. Performing t-test.")
+    # p-value calculation
+    ttest<-stats::t.test(value-control)
+    print(ttest)
+    pv<-ttest$p.value
+  }
+  # Glass' effect size. 
+  # See Glass, G.V., McGaw, B. and Smith, M.L. (1981) Meta-Analysis in Social Research. London: Sage.
+  glass<-(value-mean(control))/stats::sd(control)
+  print(paste("Glass' effect size:",glass))
+  return(c(pv,glass))
+}
+
 #real_example<-function() {
   # keys<-c("individual-based model|individual based model|individual based\\s*?[;|,]|individual-based\\s*?[;|,]", "agent-based model|agent based model|agent-based\\s*?[;|,]|agent based\\s*?[;|,]") # Includes model/modeling/modelling
   # labels<-c("IBM","ABM")
